import { Event } from "@codingame/monaco-vscode-api/vscode/vs/base/common/event";
import { URI } from "@codingame/monaco-vscode-api/vscode/vs/base/common/uri";
import { Disposable } from "@codingame/monaco-vscode-api/vscode/vs/base/common/lifecycle";
import { IInstantiationService } from "@codingame/monaco-vscode-api/vscode/vs/platform/instantiation/common/instantiation";
import { IStorageService } from "@codingame/monaco-vscode-api/vscode/vs/platform/storage/common/storage.service";
import { IOutputChannel, OutputChannelUpdateMode, IOutputChannelDescriptor } from "@codingame/monaco-vscode-api/vscode/vs/workbench/services/output/common/output";
import { IOutputService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/services/output/common/output.service";
import { ITextModelService, ITextModelContentProvider } from "@codingame/monaco-vscode-api/vscode/vs/editor/common/services/resolverService";
import { ITextModel } from "@codingame/monaco-vscode-api/vscode/vs/editor/common/model";
import { ILoggerService } from "@codingame/monaco-vscode-api/vscode/vs/platform/log/common/log.service";
import { ILogService } from "@codingame/monaco-vscode-api/vscode/vs/platform/log/common/log.service";
import { ILifecycleService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/services/lifecycle/common/lifecycle.service";
import { IOutputChannelModel } from "../common/outputChannelModel.js";
import { IViewsService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/services/views/common/viewsService.service";
import { IOutputChannelModelService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/contrib/output/common/outputChannelModelService.service";
import { ILanguageService } from "@codingame/monaco-vscode-api/vscode/vs/editor/common/languages/language";
import { IContextKeyService } from "@codingame/monaco-vscode-api/vscode/vs/platform/contextkey/common/contextkey.service";
import { IDefaultLogLevelsService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/contrib/logs/common/defaultLogLevels.service";
declare class OutputChannel extends Disposable implements IOutputChannel {
    readonly outputChannelDescriptor: IOutputChannelDescriptor;
    scrollLock: boolean;
    readonly model: IOutputChannelModel;
    readonly id: string;
    readonly label: string;
    readonly uri: URI;
    constructor(outputChannelDescriptor: IOutputChannelDescriptor, outputChannelModelService: IOutputChannelModelService, languageService: ILanguageService);
    append(output: string): void;
    update(mode: OutputChannelUpdateMode, till?: number): void;
    clear(): void;
    replace(value: string): void;
}
export declare class OutputService extends Disposable implements IOutputService, ITextModelContentProvider {
    private readonly storageService;
    private readonly instantiationService;
    private readonly logService;
    private readonly loggerService;
    private readonly lifecycleService;
    private readonly viewsService;
    private readonly defaultLogLevelsService;
    readonly _serviceBrand: undefined;
    private channels;
    private activeChannelIdInStorage;
    private activeChannel?;
    private readonly _onActiveOutputChannel;
    readonly onActiveOutputChannel: Event<string>;
    private readonly activeOutputChannelContext;
    private readonly activeFileOutputChannelContext;
    private readonly activeOutputChannelLevelSettableContext;
    private readonly activeOutputChannelLevelContext;
    private readonly activeOutputChannelLevelIsDefaultContext;
    constructor(storageService: IStorageService, instantiationService: IInstantiationService, textModelResolverService: ITextModelService, logService: ILogService, loggerService: ILoggerService, lifecycleService: ILifecycleService, viewsService: IViewsService, contextKeyService: IContextKeyService, defaultLogLevelsService: IDefaultLogLevelsService);
    provideTextContent(resource: URI): Promise<ITextModel> | null;
    showChannel(id: string, preserveFocus?: boolean): Promise<void>;
    getChannel(id: string): OutputChannel | undefined;
    getChannelDescriptor(id: string): IOutputChannelDescriptor | undefined;
    getChannelDescriptors(): IOutputChannelDescriptor[];
    getActiveChannel(): IOutputChannel | undefined;
    private onDidRegisterChannel;
    private createChannel;
    private instantiateChannel;
    private setLevelContext;
    private setLevelIsDefaultContext;
    private setActiveChannel;
}
export {};
